<?php
namespace Wookitselementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;



// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * elementor section widget.
 *
 * @since 1.0
 */
class Wookits_Product_Data_Table extends Widget_Base {

	public function get_name() {
		return 'wookits-product-data-table';
	}

	public function get_title() {
		return esc_html__( 'Product Data Table', 'wookits' );
	}

	public function get_icon() {
		return 'eicon-text';
	}

	public function get_categories() {
		return [ 'wookits-elements' ];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();


        // ---------------------------------------- Content Settings ------------------------------
        $this->start_controls_section(
            'wookits_pdata_table_content',
            [
                'label' => esc_html__( 'Content', 'wookits' ),
            ]
        );
        $this->add_control(
            'product_number',
            [
                'label' => esc_html__( 'Product Show Number', 'wookits' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 14,
                'label_block' => false
            ]
        );
        $this->add_control(
            'product_type',
                [
                    'label'     => esc_html__( 'Product Type', 'wookits' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => 'recent',
                    'options'   => [
                        'recent'     => esc_html__( 'Recent Products', 'wookits'),
                        'featured'   => esc_html__( 'Featured Products', 'wookits'),
                        'categories' => esc_html__( 'Categories Products', 'wookits' ),
                        'average_rating' => esc_html__( 'Average Rating', 'wookits' ),
                    ],
                ]
        );
        $this->add_control(
            'rating',
                [
                    'label'     => esc_html__( 'Rating', 'wookits' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => '5',
                    'options'   => [
                        '1'     => esc_html__( '1', 'wookits'),
                        '2'     => esc_html__( '2', 'wookits'),
                        '3'     => esc_html__( '3', 'wookits' ),
                        '4'     => esc_html__( '4', 'wookits' ),
                        '5'     => esc_html__( '5', 'wookits' ),
                    ],
                    'condition' => [
                        'product_type' => 'average_rating',
                    ]
                ]
        );
        $this->add_control(
            'category',
                [
                    'label'     => esc_html__( 'Categories', 'wookits' ),
                    'type'      => Controls_Manager::SELECT2,
                    'multiple'  => true,
                    'default'   => 'recent',
                    'options'   => wookits_get_product_categoris_array(),
                    'label_block' => true,
                    'condition' => [
                        'product_type' => 'categories',
                    ]
                ]
        );
        $this->add_control(
            'btn_action',
                [
                    'label'     => esc_html__( 'Action Type', 'wookits' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => 'link',
                    'options'   => [
                        'link'     => esc_html__( 'Product View Link', 'wookits'),
                        'cart'     => esc_html__( 'Add To Cart Button', 'wookits')
                    ]
                ]
        );


        $this->end_controls_section(); // End section top content

        // ---------------------------------------- Style Settings ------------------------------
        
        $this->start_controls_section(
            'wookits_table_style',
            [
                'label' => esc_html__( 'Table Style', 'wookits' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'tbl_header_footer_text_color',
            [
                'label' => esc_html__( 'Table Header/Footer Text Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper table thead tr th, {{WRAPPER}} .wookits-table-wrapper table.dataTable tfoot th, {{WRAPPER}} .wookits-table-wrapper table.dataTable tfoot td' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'tbl_header_footer_bg_color',
            [
                'label' => esc_html__( 'Table Header/Footer Background Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper table thead tr th, {{WRAPPER}} .wookits-table-wrapper table.dataTable tfoot th, {{WRAPPER}} .wookits-table-wrapper table.dataTable tfoot td' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'tbl_text_color',
            [
                'label' => esc_html__( 'Table Text Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper table' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'link_color',
            [
                'label' => esc_html__( 'Table Link Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper table a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'link_hover_color',
            [
                'label' => esc_html__( 'Table Link Hover Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper table a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'rating_color',
            [
                'label' => esc_html__( 'Rating Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper .star-rating span::before' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'table_border',
                'label' => esc_html__( 'Border', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookits-table-wrapper table.dataTable tbody td, {{WRAPPER}} .wookits-table-wrapper table.dataTable tbody th, {{WRAPPER}} .wookits-table-wrapper table.dataTable thead td, {{WRAPPER}} .wookits-table-wrapper table.dataTable thead th,{{WRAPPER}} .wookits-table-wrapper table.dataTable tfoot th',
            ]
        );
        $this->add_control(
            'tbl_even_bg_heading',
            [
                'label' => esc_html__( 'Table Even Background', 'wookits' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'tbl_even_bg',
                'label' => esc_html__( 'Table Even Background', 'wookits' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .wookits-table-wrapper table.dataTable.display tbody tr.even',
            ]
        );
        $this->add_control(
            'tbl_odd_bg_heading',
            [
                'label' => esc_html__( 'Table Odd Background', 'wookits' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'tbl_odd_bg',
                'label' => esc_html__( 'Table Odd Background', 'wookits' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .wookits-table-wrapper table.dataTable.stripe tbody tr.odd, {{WRAPPER}} .wookits-table-wrapper table.dataTable.display tbody tr.odd',
            ]
        );

        $this->end_controls_section(); // End section top content

        // ---------------------------------------- Style Settings ------------------------------
        $this->start_controls_section(
            'wookits_table_section_style',
            [
                'label' => esc_html__( 'Table Section Settings', 'wookits' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'table_section_text_color',
            [
                'label' => esc_html__( 'Table Section Text Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [

'{{WRAPPER}} .wookits-table-wrapper .dataTables_wrapper .dataTables_paginate .paginate_button,{{WRAPPER}} .wookits-table-wrapper .dataTables_wrapper .dataTables_length select,{{WRAPPER}} .wookits-table-wrapper .dataTables_wrapper .dataTables_length 
,{{WRAPPER}} .wookits-table-wrapper .dataTables_wrapper .dataTables_filter,
{{WRAPPER}} .wookits-table-wrapper .dataTables_wrapper .dataTables_info,
{{WRAPPER}} .wookits-table-wrapper .dataTables_wrapper .dataTables_processing,{{WRAPPER}} .wookits-table-wrapper .dataTables_wrapper .dataTables_filter input,{{WRAPPER}} .wookits-table-wrapper .dataTables_wrapper .dataTables_paginate' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_control(
            'pagination_hover_text_color',
            [
                'label' => esc_html__( 'Pagination Hover Text Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper .dataTables_paginate .paginate_button:not(.disabled).current,{{WRAPPER}} .wookits-table-wrapper .dataTables_paginate .paginate_button:not(.disabled):hover' => 'color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_control(
            'pagination_bg_color',
            [
                'label' => esc_html__( 'Pagination Background Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper .dataTables_paginate .paginate_button' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'pagination_hover_bg_color',
            [
                'label' => esc_html__( 'Pagination Hover Background Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper .dataTables_paginate .paginate_button:not(.disabled).current,{{WRAPPER}} .wookits-table-wrapper .dataTables_paginate .paginate_button:not(.disabled):hover' => 'background-color: {{VALUE}} !important',
                ],
            ]
        );
        $this->add_responsive_control(
            'margin',
            [
                'label' => esc_html__( 'Margin', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'padding',
            [
                'label' => esc_html__( 'Padding', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookits-table-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => esc_html__( 'Box Shadow', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookits-table-wrapper',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background',
                'label' => esc_html__( 'Background', 'wookits' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .wookits-table-wrapper',
            ]
        );
        
        $this->end_controls_section(); // End section top content

	}

	protected function render() {

    $settings = $this->get_settings_for_display();

    $limit = !empty( $settings['product_number'] ) ? $settings['product_number'] : "12";


    $featured       = false;
    $category       = '';
    $average_rating = '';

    if( $settings['product_type'] == 'featured' ) {

        $featured = true;

    } elseif( $settings['product_type'] == 'categories' ) {

        $category = !empty( $settings['category'] ) ? $settings['category']: '';

    } elseif( $settings['product_type'] == 'average_rating' ) {

        $rating = !empty( $settings['rating'] ) ? $settings['rating'] :"";
        $average_rating = esc_html( $rating );
    }


    $args = array(
        'limit' => esc_html( $limit ),
        'featured' => $featured,
        'category' => $category,
        'average_rating' => $average_rating,
    );

    $products = wc_get_products( $args );

    ?>
    <div class="wookits-table-wrapper">
        <table id="product-data-tbl" class="display product-data-tbl" style="width:100%">
            <thead>
                <tr>
                    <th><?php esc_html_e( 'Image', 'wookits' ); ?></th>
                    <th><?php esc_html_e( 'Title', 'wookits' ); ?></th>
                    <th><?php esc_html_e( 'Price', 'wookits' ); ?></th>
                    <th><?php esc_html_e( 'Review', 'wookits' ); ?></th>
                    <th><?php esc_html_e( 'Action', 'wookits' ); ?></th>
                </tr>
            </thead>
            <tbody>
                <?php 
                foreach( $products as $product ) {
                    $rating = $product->get_average_rating();
                    $count = $product->get_review_count();
                    $currencySymbol = get_woocommerce_currency_symbol();
                    $id = $product->get_ID();
                    $sku = $product->get_sku();
                ?>
                <tr>
                    <td><?php echo $product->get_image(); ?></td>
                    <td><?php echo esc_html( $product->get_name() );?></td>
                    <td>
                        <?php 
                        if( !empty( $product->get_sale_price() ) && !empty( $product->get_regular_price() ) ) {
                            echo '<span><del>'.esc_html( $currencySymbol.$product->get_regular_price() ).'</del></span><span><ins>'.esc_html( $currencySymbol.$product->get_sale_price() ).'</ins></span>';
                        } else {
                            echo '<span>'.esc_html( $currencySymbol.$product->get_price() ).'</span>';
                        }
                        ?>
                    </td>
                    <td><?php echo wc_get_rating_html( $rating, $count );?></td>
                    <td>
                        <?php 
                        if( $settings['btn_action'] != 'link' ):
                        ?>
                        <a href="?add-to-cart=<?php echo esc_html( $id ); ?>" data-quantity="1" class="button product_type_simple add_to_cart_button ajax_add_to_cart" data-product_id="<?php echo esc_attr( $id ); ?>" data-product_sku="<?php echo esc_attr( $sku ); ?>" rel="nofollow"><?php esc_html_e( 'Add to cart', 'wookits' ); ?></a>
                        <?php 
                        else:
                        ?>
                        <a href="<?php echo get_permalink( $id ); ?>"><?php esc_html_e( 'View Details', 'wookits' ); ?></a>
                        <?php
                        endif;
                        ?>
                    </td>
                </tr>
                <?php
                }
                ?>
                            
            </tbody>
            <tfoot>
                <tr>
                    <th><?php esc_html_e( 'Image', 'wookits' ); ?></th>
                    <th><?php esc_html_e( 'Title', 'wookits' ); ?></th>
                    <th><?php esc_html_e( 'Price', 'wookits' ); ?></th>
                    <th><?php esc_html_e( 'Review', 'wookits' ); ?></th>
                    <th><?php esc_html_e( 'Action', 'wookits' ); ?></th>
                </tr>
            </tfoot>
        </table>
    </div>
    <?php
      
    }

}
