<?php
namespace Wookitselementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;



// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 *
 * elementor section widget.
 *
 * @since 1.0
 */
class Wookits_Product_Search extends Widget_Base {

	public function get_name() {
		return 'wookits-product-search';
	}

	public function get_title() {
		return esc_html__( 'Product Search', 'wookits' );
	}

	public function get_icon() {
		return 'eicon-animation-text';
	}

	public function get_categories() {
		return [ 'wookits-elements' ];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();


        // ---------------------------------------- Product Showcase Content Settings ------------------------------
        $this->start_controls_section(
            'wookits_product_search',
            [
                'label' => esc_html__( 'Product Search', 'wookits' ),
            ]
        );
                
        $this->add_control(
            'placeholder_text',
            [
                'label' => esc_html__( 'Placeholder Text', 'wookits' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true
            ]
        );
        $this->add_control(
            'type',
                [
                    'label'     => esc_html__( 'Type', 'wookits' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => 'list',
                    'options'   => [
                        'list'     => esc_html__( 'List', 'wookits'),
                        'grid'     => esc_html__( 'Grid', 'wookits' ),
                    ],
                ]
        );
        $this->add_control(
            'column',
                [
                    'label'     => esc_html__( 'Column', 'wookits' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => '4',
                    'options'   => [
                        '6'     => esc_html__('2 Column', 'wookits'),
                        '4'     => esc_html__( '3 Column', 'wookits' ),
                        '3'     => esc_html__( '4 Column', 'wookits' ),
                    ],
                ]
        );
        $this->add_control(
            'text_align',
            [
                'label' => esc_html__( 'Text Alignment', 'wookits' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'wookits' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'wookits' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'wookits' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default' => 'left',
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-item' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section(); // End section top content

        // ---------------------------------------- Search Style Settings ------------------------------
        $this->start_controls_section(
            'wookits_search_style',
            [
                'label' => esc_html__( 'Style Search Area', 'wookits' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
       
        $this->add_control(
            'search_wrapper_height',
            [
                'label' => esc_html__( 'Height', 'wookits' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px','%' ],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 2000,
                        'step' => 1,
                    ]
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 100,
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookits-product-search' => 'height: {{size}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'search_margin',
            [
                'label' => esc_html__( 'Margin', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookits-product-search' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'search_padding',
            [
                'label' => esc_html__( 'Padding', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookits-product-search' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'search_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookits-product-search',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'search_border',
                'label' => esc_html__( 'Border', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookits-product-search',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'search_background',
                'label' => esc_html__( 'Background', 'wookits' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .wookits-product-search',
            ]
        );
        $this->end_controls_section(); // End section top content

        // ---------------------------------------- Grid Product Area Style Settings ------------------------------
        $this->start_controls_section(
            'wookits_grid_product_style',
            [
                'label' => esc_html__( 'Grid Product Style', 'wookits' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                'type' => 'grid'
                ],
                
            ]
        );
       
        $this->add_responsive_control(
            'grid_product_margin',
            [
                'label' => esc_html__( 'Margin', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-grid .wookit-product-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'product_grid_padding',
            [
                'label' => esc_html__( 'Padding', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-grid .wookit-product-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'product_grid_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookit-product-grid .wookit-product-item',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'product_grid_border',
                'label' => esc_html__( 'Border', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookit-product-grid .wookit-product-item',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'product_grid_background',
                'label' => esc_html__( 'Background', 'wookits' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .wookit-product-grid .wookit-product-item',
            ]
        );
        $this->end_controls_section(); // End section top content

        // ---------------------------------------- Grid Product Info Settings ------------------------------
        $this->start_controls_section(
            'wookits_grid_product_info_area_settings',
            [
                'label' => esc_html__( 'Grid Product Info Area Settings', 'wookits' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'type' => 'grid'
                ],
            ]
        );
       
        $this->add_responsive_control(
            'grid_product_info_area_margin',
            [
                'label' => esc_html__( 'Margin', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-grid .product-data' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'product_grid_info_area_padding',
            [
                'label' => esc_html__( 'Padding', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-grid .product-data' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'product_grid_info_area_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookit-product-grid .product-data',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'product_grid_info_area_border',
                'label' => esc_html__( 'Border', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookit-product-grid .product-data',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'product_grid_info_area_background',
                'label' => esc_html__( 'Background', 'wookits' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .wookit-product-grid .product-data',
            ]
        );
        $this->end_controls_section(); // End section top content

        // ---------------------------------------- Grid Product info Color Style ------------------------------
        $this->start_controls_section(
            'wookits_grid_product_info_style',
            [
                'label' => esc_html__( 'Grid Product Info Color Style', 'wookits' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                'type' => 'grid'
                ],
            ]
        );
        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-grid .product-data h3' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => esc_html__( 'Title Typography', 'wookits' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .wookit-product-grid .product-data h3',
            ]
        );
        $this->add_control(
            'price_color',
            [
                'label' => esc_html__( 'Price Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-grid .product-data .sale-price' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'regular_price_color',
            [
                'label' => esc_html__( 'Regular Price Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-grid .product-data .regular-price' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'price_typography',
                'label' => esc_html__( 'Price Typography', 'wookits' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .wookit-product-grid .product-data .product-price span',
            ]
        );
        $this->add_control(
            'rating_color',
            [
                'label' => esc_html__( 'Rating Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-grid .product-data .star-rating span:before' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'link_color',
            [
                'label' => esc_html__( 'Link Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-grid .product-data a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'link_hover_color',
            [
                'label' => esc_html__( 'Link Hover Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookit-product-grid .product-data a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'link_typography',
                'label' => esc_html__( 'Link Typography', 'wookits' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .wookit-product-grid .product-data a',
            ]
        );
        $this->end_controls_section(); // End section top content

        // ---------------------------------------- Product List area Style ------------------------------
        $this->start_controls_section(
            'wookits_product_list_area_style',
            [
                'label' => esc_html__( 'Product List Area Style', 'wookits' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                'type' => 'list'
                ],
            ]
        );
        $this->add_control(
            'list_title_color',
            [
                'label' => esc_html__( 'Title Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-search-result h3' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'text_color',
            [
                'label' => esc_html__( 'Text Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-search-result .product-categories,{{WRAPPER}} .wookits-search-result .product-sku,{{WRAPPER}} .wookits-search-result .product-price' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'list_stock_bg',
            [
                'label' => esc_html__( 'Stock Background', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-search-result .product-data .product-stock' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'list_stock_text_color',
            [
                'label' => esc_html__( 'Stock Text Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-search-result .product-data .product-stock' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'product_list_item_border',
                'label' => esc_html__( 'Item Border', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookits-search-result ul.wookits-product-search-list li',
            ]
        );
        $this->end_controls_section(); // End section top content
        // ---------------------------------------- Product List area settings Style ------------------------------
        $this->start_controls_section(
            'wookits_product_list_area_settings',
            [
                'label' => esc_html__( 'Product List Area Settings', 'wookits' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                'type' => 'list'
                ],
            ]
        );

        $this->add_responsive_control(
            'product_list_area_margin',
            [
                'label' => esc_html__( 'Margin', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookits-search-result ul.wookits-product-search-list' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );
        $this->add_responsive_control(
            'product_list_area_padding',
            [
                'label' => esc_html__( 'Padding', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookits-search-result ul.wookits-product-search-list' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'product_list_area_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookits-search-result ul.wookits-product-search-list',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'product_list_area_border',
                'label' => esc_html__( 'Border', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookits-search-result ul.wookits-product-search-list',
            ]
        ); 
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'list_area_background',
                'label' => esc_html__( 'Background', 'wookits' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .wookits-search-result ul.wookits-product-search-list',
            ]
        );

        $this->end_controls_section(); // End section top content


	}

	protected function render() {

    $settings = $this->get_settings();

    $type = !empty( $settings['type'] ) ? $settings['type']  : 'list';

    $placeHolder = !empty( $settings['placeholder_text'] ) ? $settings['placeholder_text']  : esc_html__( 'Search products....', 'wookits' );
    ?>
    <div class="wookit-container">
        <div class="wookits-product-search" data-type="<?php echo esc_attr( $type ); ?>">
            <div class="field-group">
                <input type="text" placeholder="<?php echo esc_html( $placeHolder ) ?>" class="wookits_search_input" name="wookits-search" />
                <select name="product_category" class="product-category" >
                    <?php 
                    $cats = wookits_get_product_category();
                    echo '<option value="ALL">'.esc_html__( 'ALL', 'wookits' ).'</option>';
                    foreach( $cats as $cat ) {

                        echo '<option value="'.esc_attr( $cat->term_id ).'">'.esc_html( $cat->name ).'</option>';
                    }
                    ?>
                </select>
            </div>
        </div>
        <div class="wookits-search-result"></div>
    </div>
    <?php
    }

	
}

        