<?php
namespace Wookitselementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;


// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 *
 * elementor section widget.
 *
 * @since 1.0
 */
class Wookits_Product_Slider extends Widget_Base {

	public function get_name() {
		return 'wookits-product-slider';
	}

	public function get_title() {
		return esc_html__( 'Product Slider', 'wookits' );
	}

	public function get_icon() {
		return 'eicon-divider';
	}

	public function get_categories() {
		return [ 'wookits-elements' ];
	}

	protected function _register_controls() {

		$repeater = new \Elementor\Repeater();


        // ---------------------------------------- Content Settings ------------------------------
        $this->start_controls_section(
            'wookits_product_slider',
            [
                'label' => esc_html__( 'Product Settings', 'wookits' ),
            ]
        );
        $this->add_control(
            'product_number',
            [
                'label' => esc_html__( 'Product Show Number', 'wookits' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 14,
                'label_block' => false
            ]
        );
        $this->add_control(
            'product_type',
                [
                    'label'     => esc_html__( 'Product Type', 'wookits' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => 'recent',
                    'options'   => [
                        'recent'     => esc_html__( 'Recent Products', 'wookits'),
                        'featured'   => esc_html__( 'Featured Products', 'wookits'),
                        'categories' => esc_html__( 'Categories Products', 'wookits' ),
                        'average_rating' => esc_html__( 'Average Rating', 'wookits' ),
                    ],
                ]
        );
        $this->add_control(
            'rating',
                [
                    'label'     => esc_html__( 'Rating', 'wookits' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => '5',
                    'options'   => [
                        '1'     => esc_html__( '1', 'wookits'),
                        '2'     => esc_html__( '2', 'wookits'),
                        '3'     => esc_html__( '3', 'wookits' ),
                        '4'     => esc_html__( '4', 'wookits' ),
                        '5'     => esc_html__( '5', 'wookits' ),
                    ],
                    'condition' => [
                        'product_type' => 'average_rating',
                    ]
                ]
        );
        $this->add_control(
            'category',
                [
                    'label'     => esc_html__( 'Categories', 'wookits' ),
                    'type'      => Controls_Manager::SELECT2,
                    'multiple'  => true,
                    'default'   => 'recent',
                    'options'   => wookits_get_product_categoris_array(),
                    'label_block' => true,
                    'condition' => [
                        'product_type' => 'categories',
                    ]
                ]
        );

        $this->end_controls_section(); // End section top content

        // ---------------------------------------- Slider Settings ------------------------------
        $this->start_controls_section(
            'wookits_slider_settings',
            [
                'label' => esc_html__( 'Slider Settings', 'wookits' ),
            ]
        );
        $this->add_control(
            'item_per_slide',
            [
                'label' => esc_html__( 'Item Per Slide', 'wookits' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 3,
                'label_block' => false
            ]
        );
        $this->add_control(
            'slider_nav',
            [
                'label' => esc_html__( 'Show Nav', 'wookits' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'wookits' ),
                'label_off' => esc_html__( 'Hide', 'wookits' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );
        $this->add_control(
            'slider_dot',
            [
                'label' => esc_html__( 'Show Dots', 'wookits' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'wookits' ),
                'label_off' => esc_html__( 'Hide', 'wookits' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'slider_autoplay',
            [
                'label' => esc_html__( 'Autoplay', 'wookits' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'wookits' ),
                'label_off' => esc_html__( 'No', 'wookits' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'slider_loop',
            [
                'label' => esc_html__( 'Loop', 'wookits' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'wookits' ),
                'label_off' => esc_html__( 'No', 'wookits' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->end_controls_section(); // End section top content

        // ---------------------------------------- Content Style Settings ------------------------------
        $this->start_controls_section(
            'item_wookits_content_style',
            [
                'label' => esc_html__( 'Content Style', 'wookits' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'item_title_color',
            [
                'label' => esc_html__( 'Title Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .single-slider .wookits-product-info h4' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'item_price_color',
            [
                'label' => esc_html__( 'Price Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .single-slider .wookits-product-info .product-price' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'item_price_del_color',
            [
                'label' => esc_html__( 'Del Price Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .single-slider .product-price span del' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'item_link_color',
            [
                'label' => esc_html__( 'Link Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-product-info a' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'item_link_hover_color',
            [
                'label' => esc_html__( 'Link Hover Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .wookits-product-info a:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'item_rating_color',
            [
                'label' => esc_html__( 'Rating Color', 'wookits' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .single-slider .star-rating span:before' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_responsive_control(
            'item_margin',
            [
                'label' => esc_html__( 'Margin', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .single-slider' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'item_padding',
            [
                'label' => esc_html__( 'Padding', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .single-slider' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'item_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'wookits' ),
                'selector' => '{{WRAPPER}} .single-slider',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'item_border',
                'label' => esc_html__( 'Border', 'wookits' ),
                'selector' => '{{WRAPPER}} .single-slider',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'item_background',
                'label' => esc_html__( 'Background', 'wookits' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .single-slider',
            ]
        );


        $this->end_controls_section(); // End section top content

        // ---------------------------------------- Content Style Settings ------------------------------
        $this->start_controls_section(
            'wookits_section_settings',
            [
                'label' => esc_html__( 'Section Settings', 'wookits' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'margin',
            [
                'label' => esc_html__( 'Margin', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookits-product-slider' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'padding',
            [
                'label' => esc_html__( 'Padding', 'wookits' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'desktop_default' => [
                    'size' => 30,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 20,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 10,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wookits-product-slider' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => esc_html__( 'Box Shadow', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookits-product-slider',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => esc_html__( 'Border', 'wookits' ),
                'selector' => '{{WRAPPER}} .wookits-product-slider',
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'background',
                'label' => esc_html__( 'Background', 'wookits' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .wookits-product-slider',
            ]
        );
        $this->end_controls_section(); // End section top content



	}

	protected function render() {

    $settings = $this->get_settings();
    
    
    $limit = !empty( $settings['product_number'] ) ? $settings['product_number'] : "12";

    $itemPerSlide       = !empty( $settings['item_per_slide'] ) ? $settings['item_per_slide'] : "3";
    $sliderNav          = !empty( $settings['slider_nav'] ) ? 'true' : 'false';
    $sliderDot          = !empty( $settings['slider_dot'] ) ? 'true' : 'false';
    $sliderAutoplay     = !empty( $settings['slider_autoplay'] ) ? 'true' : 'false';
    $sliderLoop         = !empty( $settings['slider_loop'] ) ? 'true' : 'false';

    $featured       = false;
    $category       = '';
    $average_rating = '';

    if( $settings['product_type'] == 'featured' ) {

        $featured = true;

    } elseif( $settings['product_type'] == 'categories' ) {

        $category = !empty( $settings['category'] ) ? $settings['category']: '';

    } elseif( $settings['product_type'] == 'average_rating' ) {

        $rating = !empty( $settings['rating'] ) ? $settings['rating'] :"";
        $average_rating = esc_html( $rating );
    }


    $args = array(
        'limit' => esc_html( $limit ),
        'featured' => $featured,
        'category' => $category,
        'average_rating' => $average_rating,
    );

    $products = wc_get_products( $args );
 
      ?>
        <!-- Set up your HTML -->
        <div class="wookits-product-slider owl-carousel" data-slide="<?php echo esc_html( $itemPerSlide ); ?>" data-nav="<?php echo esc_html( $sliderNav ); ?>" data-dot="<?php echo esc_html( $sliderDot ); ?>" data-autoplay="<?php echo esc_html( $sliderAutoplay ); ?>" data-loop="<?php echo esc_html( $sliderLoop ); ?>">
            <?php 
            foreach( $products as $product ) {
                $rating = $product->get_average_rating();
                $count = $product->get_review_count();
                $currencySymbol = get_woocommerce_currency_symbol();
               ?>
               <div class="single-slider style-border">
                    <div class="singel-slider-inner">
                        <div class="wookits-product-img">
                        <?php echo $product->get_image(); ?>
                        </div>
                        <div class="wookits-product-info">
                            <h4><?php echo $product->get_name();?></h4>
                            <div class="product-rating">
                                <?php echo wc_get_rating_html( $rating, $count );?>
                            </div>
                            <div class="product-price">
                            <?php 
                            if( !empty( $product->get_sale_price() ) && !empty( $product->get_regular_price() ) ) {
                                echo '<span><del>'.esc_html( $currencySymbol.$product->get_regular_price() ).'</del></span><span><ins>'.esc_html( $currencySymbol.$product->get_sale_price() ).'</ins></span>';
                            } else {
                                echo '<span>'.esc_html( $currencySymbol.$product->get_price() ).'</span>';
                            }
                            ?>
                            </div>
                            <a href="<?php echo get_permalink( $product->get_id() ); ?>">View Details</a>
                        </div>
                    </div>
               </div>
               <?php
            }
            ?>
        </div>

      <?php

    }

	
}
