<?php
add_action( 'wp_ajax_wookits_search_product', 'search_product' );
add_action( 'wp_ajax_nopriv_wookits_search_product', 'search_product' );
function search_product() {
 
    global $wpdb, $woocommerce;
 
    if (isset($_POST['keyword']) && !empty($_POST['keyword'])) {
 
        $keyword = sanitize_text_field( $_POST['keyword'] );
 
        if (isset($_POST['category']) && !empty( $_POST['category'] ) && $_POST['category'] != 'ALL'  ) {
 
            $category = sanitize_text_field( $_POST['category'] );
 
            $querystr = $wpdb->prepare(
            "
            SELECT DISTINCT * FROM $wpdb->posts AS p
            LEFT JOIN $wpdb->term_relationships AS r ON (p.ID = r.object_id)
            INNER JOIN $wpdb->term_taxonomy AS x ON (r.term_taxonomy_id = x.term_taxonomy_id)
            INNER JOIN $wpdb->terms AS t ON (r.term_taxonomy_id = t.term_id)
            WHERE p.post_type IN ('product')
            AND p.post_status = 'publish'
            AND x.taxonomy = 'product_cat'
            AND (
                (x.term_id = {$category})
                OR
                (x.parent = {$category})
            )
            AND (
                (p.ID IN (SELECT post_id FROM $wpdb->postmeta WHERE meta_key = '_sku' AND meta_value LIKE '%{$keyword}%'))
                OR
                (p.post_content LIKE '%{$keyword}%')
                OR
                (p.post_title LIKE '%{$keyword}%')
            )
            ORDER BY t.name ASC, p.post_date DESC;
            "
        );
 
        } else {
            $querystr = $wpdb->prepare(
            "
            SELECT DISTINCT $wpdb->posts.*
            FROM $wpdb->posts, $wpdb->postmeta
            WHERE $wpdb->posts.ID = $wpdb->postmeta.post_id
            AND (
                ($wpdb->postmeta.meta_key = '_sku' AND $wpdb->postmeta.meta_value LIKE '%{$keyword}%')
                OR
                ($wpdb->posts.post_content LIKE '%{$keyword}%')
                OR
                ($wpdb->posts.post_title LIKE '%{$keyword}%')
            )
            AND $wpdb->posts.post_status = 'publish'
            AND $wpdb->posts.post_type = 'product'
            ORDER BY $wpdb->posts.post_date DESC
            "            
            );
        }
 
        $query_results = $wpdb->get_results($querystr);

 
        if( !empty( $_POST['type'] ) && $_POST['type'] == 'list' ) {
            template_list( $query_results );
        } else {
            template_grid( $query_results );
        }
   
    
    }

    exit;

}


// search template list

function template_list( $data ) {

    if ( !empty( $data ) ) {

            ob_start();
            $output = '';
            $output .= '<ul class="wookits-product-search-list">';
 
            foreach ($data as $result ) {
 
                $price          = get_post_meta( $result->ID, '_price' );
                $regular_price  = get_post_meta( $result->ID, '_regular_price' );
                $price_sale     = get_post_meta( $result->ID, '_sale_price' );
                $currency   = get_woocommerce_currency_symbol();
 
                $sku   = get_post_meta($result->ID,'_sku');
                $stock = get_post_meta($result->ID,'_stock_status');
 
                $categories = wp_get_post_terms($result->ID, 'product_cat');
 
                $output .= '<li>';
                    $output .= '<a href="'.get_post_permalink($result->ID).'">';
                        $output .= '<div class="product-image">';
                            $output .= '<img src="'.esc_url(get_the_post_thumbnail_url($result->ID,'thumbnail')).'">';
                        $output .= '</div>';
                        $output .= '<div class="product-data">';
                        $output .= '<div class="product-data-left">';
                            $output .= '<h3>'.$result->post_title.'</h3>';
                            if (!empty($categories)) {
                                $output .= '<div class="product-categories">';
                                    foreach ($categories as $category) {
                                        if ($category->parent) {
                                            $parent = get_term_by('id',$category->parent,'product_cat');
                                            $output .= '<span>'.$parent->name.'</span>';
                                        }
                                        $output .= '<span>'.$category->name.'</span>';
                                    }
                                $output .= '</div>';
                            }
                            if (!empty($sku)) {
                                $output .= '<div class="product-sku">'.esc_html__( 'SKU:', 'wookits' ).' '.$sku[0].'</div>';
                            }
                            $output .= '</div>';
                            $output .= '<div class="product-data-right">';

                            $output .= '<div class="product-price">';
                            //
                            if( count( $price ) > 1 ) {
                                $output .= '<span class="sale-price">'.esc_html( $currency.$price[0] ).' - '.esc_html( $currency.$price[1] ).'</span>';
                            }elseif ( !empty( $price_sale[0] ) && !empty( $regular_price[0] )  ) {
                                $output .= '<span class="regular-price"><del>'.esc_html( $currency.$regular_price[0] ).'</del></span>';
                                $output .= '<span class="sale-price">'.esc_html( $currency.$price_sale[0] ).'</span>';

                            } else{
                             
                                $output .= '<span class="sale-price">'.esc_html( $currency.$price[0] ).'</span>';
                                
                            }

                            $output .= '</div>';

                            if (!empty($stock)) {
                                $output .= '<div class="product-stock">'.$stock[0].'</div>';
                            }
                            $output .= '</div>';
 
                        $output .= '</div>';
                        $output .= '</a>';
                $output .= '</li>';
            }
 
            $output .= '</ul>';

            

            if ( !empty( $output ) ) {

                echo $output;

            }

        } else {
            esc_html_e( 'Product not found.', 'wookits' );
        }

        echo ob_get_clean();


}


// search template grid

function template_grid( $data ) {

    if ( !empty( $data ) ) {

            ob_start();
            $output = '';

            $output .= '<div class="wookit-row wookit-product-grid">';
 
            foreach ( $data as $result ) {
 
                $price          = get_post_meta( $result->ID, '_price' );
                $regular_price  = get_post_meta( $result->ID, '_regular_price' );
                $price_sale     = get_post_meta( $result->ID, '_sale_price' );
                $currency       = get_woocommerce_currency_symbol();
 
                $sku   = get_post_meta( $result->ID, '_sku' );
                $stock = get_post_meta( $result->ID, '_stock_status' );
 
                $categories = wp_get_post_terms( $result->ID, 'product_cat' );

                $url = get_post_permalink( $result->ID );

                $product = wc_get_product( $result->ID );
                $rating  = $product->get_average_rating();
                $count   = $product->get_rating_count();
 
                $output .= '<div class="wookit-col-lg-3">';
                $output .= '<div class="wookit-product-item">';
                        $output .= '<div class="product-image">';
                            $output .= '<img src="'.esc_url( get_the_post_thumbnail_url( $result->ID, 'full' ) ).'">';
                        $output .= '</div>';
                        $output .= '<div class="product-data">';
                            $output .= '<h3>'.esc_html( $result->post_title ).'</h3>';
                            $output .= '<div class="product-data-right">';
                            if ( !empty( $price ) ) {
                                $output .= '<div class="product-price">';
                                    //
                                    if( count( $price ) > 1 ) {
                                        $output .= '<span class="sale-price">'.esc_html( $currency.$price[0] ).' - '.esc_html( $currency.$price[1] ).'</span>';
                                    }elseif ( !empty( $price_sale[0] ) && !empty( $regular_price[0] )  ) {
                                        $output .= '<span class="regular-price"><del>'.esc_html( $currency.$regular_price[0] ).'</del></span>';
                                        $output .= '<span class="sale-price">'.esc_html( $currency.$price_sale[0] ).'</span>';

                                    } else{
                                     
                                        $output .= '<span class="sale-price">'.esc_html( $currency.$price[0] ).'</span>';
                                        
                                    }                                    
                                $output .= '</div>';
                            }
                            
                            $output .= wc_get_rating_html( $rating, $count );
                            $output .= '<a href="'.esc_url( $url ).'">'.esc_html( 'View Details', 'wookits' ).'</a>';
                            $output .= '</div>';
 
                        $output .= '</div>';
                $output .= '</div>';
                $output .= '</div>';
            }

            $output .= '</div>';
            
            if ( !empty( $output ) ) {

                echo $output;

            }

        } else {
            esc_html_e( 'Product not found.', 'wookits' );
        }

        echo ob_get_clean();

    
}
