<?php
 /**
  * 
  * @package    Wookits
  * @version    1.0
  * @author     WPBucket
  * @Websites: http://wpbucket.net
  *
  */
  if( ! defined( 'ABSPATH' ) ) {
      die( WOOKITS_ALERT_MSG );
  }
 

class Wookits_min_max_product_qty{

    public static function init() {

        add_action( 'woocommerce_product_options_general_product_data', __CLASS__.'::wookits_wc_qty_add_product_field' );
        add_action( 'woocommerce_process_product_meta', __CLASS__.'::wookits_wc_qty_save_product_field' );
        add_filter( 'woocommerce_quantity_input_args', __CLASS__.'::wookits_wc_qty_input_args', 10, 2 );
        add_filter( 'woocommerce_add_to_cart_validation', __CLASS__.'::wookits_wc_qty_add_to_cart_validation', 1, 5 );

    }

    // Add quantity field in product inventory tab
    public static function wookits_wc_qty_add_product_field() {

        echo '<div class="options_group">';
        woocommerce_wp_text_input( 
            array( 
                'id'          => '_wookits_wc_min_qty_product', 
                'label'       => esc_html__( 'Minimum Quantity', 'wookits' ), 
                'placeholder' => '',
                'desc_tip'    => 'true',
                'description' => esc_html__( 'Optional. Set a minimum quantity limit allowed per order. Enter a number, 1 or greater.', 'wookits' ) 
            )
        );
        echo '</div>';
        echo '<div class="options_group">';
        woocommerce_wp_text_input(
            array( 
                'id'          => '_wookits_wc_max_qty_product', 
                'label'       => esc_html__( 'Maximum Quantity', 'wookits' ), 
                'placeholder' => '',
                'desc_tip'    => 'true',
                'description' => esc_html__( 'Optional. Set a maximum quantity limit allowed per order. Enter a number, 1 or greater.', 'wookits' ) 
            )
        );
        echo '</div>';  

    }


    // Save quantity field data

    public static function wookits_wc_qty_save_product_field( $post_id ) {

        $val_min = trim( get_post_meta( $post_id, '_wookits_wc_min_qty_product', true ) );
        $new_min = sanitize_text_field( $_POST['_wookits_wc_min_qty_product'] );
        $val_max = trim( get_post_meta( $post_id, '_wookits_wc_max_qty_product', true ) );
        $new_max = sanitize_text_field( $_POST['_wookits_wc_max_qty_product'] );
        
        if ( $val_min != $new_min ) {
            update_post_meta( $post_id, '_wookits_wc_min_qty_product', $new_min );
        }
        if ( $val_max != $new_max ) {
            update_post_meta( $post_id, '_wookits_wc_max_qty_product', $new_max );
        }
    }


    /*
    * Setting minimum and maximum for quantity input args. 
    */


    public static function wookits_wc_qty_input_args( $args, $product ) {
        
        // Global option
        
        $getmin = get_option( 'wc_wookits_settings_tab_min_qty');
        $getmax = get_option( 'wc_wookits_settings_tab_max_qty');

        //
        $product_id = $product->get_parent_id() ? $product->get_parent_id() : $product->get_id();
        
        $product_min = self::wookits_wc_get_product_min_limit( $product_id );
        $product_max = self::wookits_wc_get_product_max_limit( $product_id ); 

        // Global min and max qty settings

        if( $getmin ) {
            $args['min_value'] = $getmin;
        }
        
        if( $getmax ) {
            $args['max_value'] = $getmax;
        }
        



        if ( ! empty( $product_min ) ) {
            // min is empty
            if ( false !== $product_min ) {
                $args['min_value'] = $product_min;
            }
        }
        if ( ! empty( $product_max ) ) {
            // max is empty
            if ( false !== $product_max ) {
                $args['max_value'] = $product_max;
            }
        }
        if ( $product->managing_stock() && ! $product->backorders_allowed() ) {
            $stock = $product->get_stock_quantity();
            $args['max_value'] = min( $stock, $args['max_value'] ); 
        }





        return $args;
    }

    // Get product max limit
    public static function wookits_wc_get_product_max_limit( $product_id ) {
        $qty = get_post_meta( $product_id, '_wookits_wc_max_qty_product', true );
        if ( empty( $qty ) ) {
            $limit = false;
        } else {
            $limit = (int) $qty;
        }
        return $limit;
    }

    // Get product min limit
    public static function wookits_wc_get_product_min_limit( $product_id ) {
        $qty = get_post_meta( $product_id, '_wookits_wc_min_qty_product', true );
        if ( empty( $qty ) ) {
            $limit = false;
        } else {
            $limit = (int) $qty;
        }
        return $limit;
    }



    /**
     * Validating the quantity on add to cart action with the quantity of the same product available in the cart. 
     */
    public static function wookits_wc_qty_add_to_cart_validation( $passed, $product_id, $quantity, $variation_id = '', $variations = '' ) {
        $product_min = self::wookits_wc_get_product_min_limit( $product_id );
        $product_max = self::wookits_wc_get_product_max_limit( $product_id );
        if ( ! empty( $product_min ) ) {
            // min is empty
            if ( false !== $product_min ) {
                $new_min = $product_min;
            } else {
                // neither max is set, so get out
                return $passed;
            }
        }
        if ( ! empty( $product_max ) ) {
            // min is empty
            if ( false !== $product_max ) {
                $new_max = $product_max;
            } else {
                // neither max is set, so get out
                return $passed;
            }
        }

        $already_in_cart    = self::wookits_wc_qty_get_cart_qty( $product_id );
        $product            = wc_get_product( $product_id );
        $product_title      = $product->get_title();
        
        if ( !empty( $new_max ) && !empty( $already_in_cart ) ) {
            
            if ( ( $already_in_cart + $quantity ) > $new_max ) {
                // oops. too much.
                $passed = false;            
                wc_add_notice( apply_filters( 'isa_wc_max_qty_error_message_already_had', sprintf( esc_html__( 'You can add a maximum of %1$s %2$s\'s to %3$s. You already have %4$s.', 'wookits' ), 
                            $new_max,
                            $product_title,
                            '<a href="' . esc_url( wc_get_cart_url() ) . '">' . esc_html__( 'your cart', 'wookits' ) . '</a>',
                            $already_in_cart ),
                        $new_max,
                        $already_in_cart ),
                'error' );
            }
        }
        return $passed;
    }

    /**
     * Get the total quantity of the product available in the cart.
     */ 
    public static function wookits_wc_qty_get_cart_qty( $product_id ) {
        global $woocommerce;
        $running_qty = 0; // iniializing quantity to 0
        // search the cart for the product in and calculate quantity.
        foreach($woocommerce->cart->get_cart() as $other_cart_item_keys => $values ) {
            if ( $product_id == $values['product_id'] ) {               
                $running_qty += (int) $values['quantity'];
            }
        }
        return $running_qty;
    }


}

Wookits_min_max_product_qty::init();