<?php
 /**
  * 
  * @package    Wookits
  * @version    1.0
  * @author     WPBucket
  * @Websites: http://wpbucket.net
  *
  */
  if( ! defined( 'ABSPATH' ) ) {
      die( WOOKITS_ALERT_MSG );
  }
 

 class Wookits_wc_Settings_Tab {
    /**
     * Bootstraps the class and hooks required actions & filters.
     *
     */
    public static function init() {
        add_filter( 'woocommerce_settings_tabs_array', __CLASS__ . '::add_settings_tab', 50 );
        add_action( 'woocommerce_settings_tabs_wookits_settings_tab', __CLASS__ . '::settings_tab' );
        add_action( 'woocommerce_update_options_wookits_settings_tab', __CLASS__ . '::update_settings' );
    }
    
    
    /**
     * Add a new settings tab to the WooCommerce settings tabs array.
     *
     * @param array $settings_tabs Array of WooCommerce setting tabs & their labels, excluding the Subscription tab.
     * @return array $settings_tabs Array of WooCommerce setting tabs & their labels, including the Subscription tab.
     */
    public static function add_settings_tab( $settings_tabs ) {
        $settings_tabs['wookits_settings_tab'] = esc_html__( 'Wookits', 'wookits' );
        return $settings_tabs;
    }
    /**
     * Uses the WooCommerce admin fields API to output settings via the @see woocommerce_admin_fields() function.
     *
     * @uses woocommerce_admin_fields()
     * @uses self::get_settings()
     */
    public static function settings_tab() {
        woocommerce_admin_fields( self::get_settings() );
    }
    /**
     * Uses the WooCommerce options API to save settings via the @see woocommerce_update_options() function.
     *
     * @uses woocommerce_update_options()
     * @uses self::get_settings()
     */
    public static function update_settings() {
        woocommerce_update_options( self::get_settings() );
    }
    /**
     * Get all the settings for this plugin for @see woocommerce_admin_fields() function.
     *
     * @return array Array of settings for @see woocommerce_admin_fields() function.
     */
    public static function get_settings() {
        $settings = array(
            'section_title' => array(
                'name'     => esc_html__( 'Wookits Settings Options', 'wookits' ),
                'type'     => 'title',
                'desc'     => '',
                'id'       => 'wookits_wc_settings_tab_section_title'
            ),
            'minqty' => array(
                'name' => esc_html__( 'Minimum Quantity', 'wookits' ),
                'type' => 'number',
                'desc' => esc_html__( 'Optional. Set a minimum quantity limit allowed per order. Enter a number, 1 or greater.', 'wookits' ),
                'id'   => 'wc_wookits_settings_tab_min_qty'
            ),
            'maxqty' => array(
                'name' => esc_html__( 'Maximum Quantity', 'wookits' ),
                'type' => 'number',
                'desc' => esc_html__( 'Optional. Set a maximum quantity limit allowed per order. Enter a number, 1 or greater.', 'wookits' ),
                'id'   => 'wc_wookits_settings_tab_max_qty'
            ),
            'minamount' => array(
                'name' => esc_html__( 'Minimum Order Amount', 'wookits' ),
                'type' => 'number',
                'desc' => esc_html__( 'Set a minimum order amount allowed per order.', 'wookits' ),
                'id'   => 'wc_wookits_settings_tab_minimum_amount'
            ),
            'hideprice' => array(
                'name' => esc_html__( 'Hide price for guest user', 'wookits' ),
                'type' => 'checkbox',
                'desc' => esc_html__( 'Product price don\'t show when guest user visit the shop, product detials and cart page.', 'wookits' ),
                'id'   => 'wc_wookits_settings_tab_hidepric'
            ),
            'hideaddcartbtn' => array(
                'name' => esc_html__( 'Hide add to cart for guest user', 'wookits' ),
                'type' => 'checkbox',
                'desc' => esc_html__( 'Product add to cart button don\'t show when guest user visit the shop, product detials.', 'wookits' ),
                'id'   => 'wc_wookits_settings_tab_hidaddtocartbtn'
            ),
            'section_end' => array(
                 'type' => 'sectionend',
                 'id' => 'wookits_wc_settings_tab_section_end'
            )
        );
        return apply_filters( 'wookits_wc_settings_tab', $settings );
    }
}
Wookits_wc_Settings_Tab::init();